@@ -155,6 +155,7 @@ getexportent(int fromkernel, int fromexports)
 	}
 
 	xfree(ee.e_hostname);
+	xfree(ee.e_realpath);
 	ee = def_ee;
 
 	/* Check for default client */
@@ -179,9 +180,20 @@ getexportent(int fromkernel, int fromexports)
 	}
 	ee.e_hostname = xstrdup(hostname);
 
-	if (parseopts(opt, &ee, fromexports && !has_default_subtree_opts, NULL) < 0)
-		return NULL;
+	if (parseopts(opt, &ee, fromexports && !has_default_subtree_opts, NULL) < 0) {
+                if(ee.e_hostname)
+                {
+                    xfree(ee.e_hostname);
+                    ee.e_hostname=NULL;
+                }
+                if(ee.e_uuid)
+                {
+                    xfree(ee.e_uuid);
+                    ee.e_uuid=NULL;
+                }
 
+		return NULL;
+        }
 	/* resolve symlinks */
 	if (realpath(ee.e_path, rpath) != NULL) {
 		rpath[sizeof (rpath) - 1] = '\0';
@@ -235,23 +247,28 @@ void secinfo_show(FILE *fp, struct exportent *ep)
 	}
 }
 
+static void
+fprintpath(FILE *fp, const char *path)
+{
+	int i;
+	for (i=0; path[i]; i++)
+		if (iscntrl(path[i]) || path[i] == '"' || path[i] == '\\' || path[i] == '#' || isspace(path[i]))
+			fprintf(fp, "\\%03o", path[i]);
+		else
+			fprintf(fp, "%c", path[i]);
+}
+
 void
 putexportent(struct exportent *ep)
 {
 	FILE	*fp;
 	int	*id, i;
-	char	*esc=ep->e_path;
 
 	if (!efp)
 		return;
 
 	fp = efp->x_fp;
-	for (i=0; esc[i]; i++)
-	        if (iscntrl(esc[i]) || esc[i] == '"' || esc[i] == '\\' || esc[i] == '#' || isspace(esc[i]))
-			fprintf(fp, "\\%03o", esc[i]);
-		else
-			fprintf(fp, "%c", esc[i]);
-
+	fprintpath(fp, ep->e_path);
 	fprintf(fp, "\t%s(", ep->e_hostname);
 	fprintf(fp, "%s,", (ep->e_flags & NFSEXP_READONLY)? "ro" : "rw");
 	fprintf(fp, "%ssync,", (ep->e_flags & NFSEXP_ASYNC)? "a" : "");
@@ -290,10 +307,14 @@ putexportent(struct exportent *ep)
 	case FSLOC_NONE:
 		break;
 	case FSLOC_REFER:
-		fprintf(fp, "refer=%s,", ep->e_fslocdata);
+		fprintf(fp, "refer=");
+		fprintpath(fp, ep->e_fslocdata);
+		fprintf(fp, ",");
 		break;
 	case FSLOC_REPLICA:
-		fprintf(fp, "replicas=%s,", ep->e_fslocdata);
+		fprintf(fp, "replicas=");
+		fprintpath(fp, ep->e_fslocdata);
+		fprintf(fp, ",");
 		break;
 #ifdef DEBUG
 	case FSLOC_STUB:
@@ -358,6 +379,7 @@ dupexportent(struct exportent *dst, struct exportent *src)
 	if (src->e_uuid)
 		dst->e_uuid = strdup(src->e_uuid);
 	dst->e_hostname = NULL;
+	dst->e_realpath = NULL;
 }
 
 struct exportent *
@@ -369,6 +391,8 @@ mkexportent(char *hname, char *path, char *options)
 
 	xfree(ee.e_hostname);
 	ee.e_hostname = xstrdup(hname);
+	xfree(ee.e_realpath);
+	ee.e_realpath = NULL;
 
 	if (strlen(path) >= sizeof(ee.e_path)) {
 		xlog(L_ERROR, "path name %s too long", path);
